@@ -4,7 +4,6 @@ from starlette.responses import Response
 from xpresso.applications import App
 from xpresso.binders._param_functions import (
     ByContentType,
-    ContentTypeDiscriminatedBody,
     CookieParam,
     ExtractField,
     ExtractRepeatedField,
@@ -32,8 +31,12 @@ from xpresso.datastructures import UploadFile
 from xpresso.dependencies.models import Dependant
 from xpresso.exceptions import HTTPException
 from xpresso.requests import Request
-from xpresso.routing import Operation, Path, Router
+from xpresso.routing.operation import Operation
+from xpresso.routing.pathitem import Path
+from xpresso.routing.router import Router
+from xpresso.routing.websockets import WebSocketRoute
 from xpresso.security._functions import Security
+from xpresso.websockets import WebSocket
 
 __all__ = (
     "Operation",
@@ -70,5 +73,6 @@ __all__ = (
     "Request",
     "Response",
     "ByContentType",
-    "ContentTypeDiscriminatedBody",
+    "WebSocketRoute",
+    "WebSocket",
 )
